@@ -53,7 +53,7 @@ class Transcription(models.Model):
             return self.log_frequency
         count = self.pronouncedas_set.all().aggregate(count = Sum('word_form__frequency'))['count']
         totCount = WordForm.objects.all().aggregate(totcount = Sum('frequency'))['totcount']
-        freq = math.log((float(count) * 1000000)/float(totCount),10)
+        freq = math.log((float(count) * 1000000)/float(totCount)+1,10)
         self.log_frequency = freq
         self.save()
         return freq
@@ -77,8 +77,8 @@ class Transcription(models.Model):
             totCount = Transcription.objects.extra(
                     where = [UR_LOOKUP],
                     params = [totPattern])
-            SPprob += float(sum([math.log(x.get_frequency(),10)
-                                    for x in count])) / float(sum([math.log(x.get_frequency(),10)
+            SPprob += float(sum([x.get_frequency()
+                                    for x in count])) / float(sum([x.get_frequency()
                                                                     for x in totCount]))
             if i != len(phones)-1:
                 patt = [any_segment] * i
@@ -91,8 +91,8 @@ class Transcription(models.Model):
                 totCount = Transcription.objects.extra(
                     where = [UR_LOOKUP],
                     params = [totPattern])
-                BPprob += float(sum([math.log(x.get_frequency(),10)
-                                    for x in count])) / float(sum([math.log(x.get_frequency(),10)
+                BPprob += float(sum([x.get_frequency()
+                                    for x in count])) / float(sum([x.get_frequency()
                                                                     for x in totCount]))
         SPprob = SPprob / float(len(phones))
         BPprob = BPprob / float(len(phones)-1)
